@@ -1,4 +1,4 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 describe WPScan::DB::Version do
   describe '#vulnerabilities' do
